#!/bin/sh
#
# $Id: import-gnusense-gdb.sh,v 1.1 2007-11-30 07:58:13 mdb Exp $
#
# Copyright (c) 2007, Juniper Networks, Inc.
# All rights reserved.
#
# This import script is to import the FSF GNU gdb sources.
# FreeBSD 6.1-RELEASE is based on the gdb-6.1.1 sources
# and is located in src/contrib/gdb and requires binutils
# and the readline library which are maintained separately.
# That release was the basis of the JUNOS 8.5 sources.
#
# This import is to be based on the official
# GNUsense sources for gdb maintained by
# Specifix.com complete with Juniper Networks
# patches.

# Set default CVS to use before processing command-line arguments
# where CVS=/some/path/name might be used.
# For FreeBSD 4.x
[ -x /volume/fwtools/cvs/1.12.9.1-JNPR/bin/cvs ] &&
CVS=${CVS:-/volume/fwtools/cvs/1.12.9.1-JNPR/bin/cvs}
# For FreeBSD 6.x
[ -x /volume/fwtools/cvs/1.12.13.0.2-JNPR_2006_2_0/bin/cvs ] &&
CVS=${CVS:-/volume/fwtools/cvs/1.12.13.0.2-JNPR_2006_2_0/bin/cvs}

# The default CVSROOT should be changed to be real before the formal import.
CVSROOT=:ext:freebase.juniper.net:/cvs/junos-2001

# The location in the repository for the imported files to live.
MODULE=src/juniper/contrib/gdb

# The version are we importing.
# Get it from the command-line or find it in a file.
VERSION=

# Process command-line arguments.
while :
do
  case "$1" in
  *=*) eval "$1"; shift;;
  --) shift; break;;
  -P) PR=$2; shift 2;;
  -h) echo "Use PR=<PR #> to specify the PR" ; exit 1;;
  -m) MESSAGE=$2; shift 2;;
  -n) ECHO=echo; shift;;
  -r) VERSION=$2; shift 2;;
  *) break;;
  esac
done

# Check to be sure a PR number was specified on the command-line.
[ "$PR" ] || { echo "We will need a PR.  Use: -P <PR>" >&2; exit 1; }

if [ -f gdb/version.in ]; then
  [ "$VERSION" ] || VERSION=`cat gdb/version.in`
else
  echo "Must be in a gdb source distribution." >&2
  exit 1;
fi

[ "$VERSION" ] || { echo "We will need a VERSION.  Use: -r <VERSION>" >&2; exit 1; }
VERSION_TAG=
case $VERSION in
[0-9]*|*[.\ ]*) VERSION_TAG=gnusense-`echo $VERSION | tr '. ' '_-'` ;;
*) VERSION_TAG=$VERSION ;;
esac

case `cat CVS/Root 2>/dev/null` in
*junos-2001*) echo "Must not be in a checked out JUNOS tree"; exit  1;;
esac

# make sure CVS is executable and supports the -X flag
[ -x "$CVS" ] || { echo "$CVS is not executable"; exit 1; }
$CVS -H import 2>&1 | egrep '^[[:space:]]*-X' >/dev/null || \
    { echo "$CVS does not support the -X flag, it is needed for this import"; \
      exit 1; }

# make sure the tag is not already used
find . -type f 2>/dev/null 2>/dev/null \
  | sed "s,^\.,$MODULE," \
  | xargs $CVS -d $CVSROOT rlog 2>/dev/null \
  | egrep "^[[:space:]]${VERSION_TAG}:[[:space:]][0-9.]+" 2>&1 >/dev/null && \
  { echo "CVS tag '$VERSION_TAG' is already being used" >&2; \
    echo "Use '-r <VERSION>' to specify another version number." >&2; \
    exit 1; }

$ECHO $CVS -d $CVSROOT import -ko -X     \
  -I examples  -I sim       -I testsuite \
  -I arm       -I avr       -I cris      \
  -I d10v      -I djgpp     -I frv       \
  -I h8300     -I iq2000    -I m32c      \
  -I m32r      -I m68hc11   -I m68k      \
  -I m88k      -I mn10300   -I mt        \
  -I pa        -I s390      -I sh        \
  -I sparc     -I v850      -I vax       \
  -I xstormy16 -I osf-share -I vx-share  \
  -m "Import gnusense-$VERSION sources as obtained from specifix.com
$MESSAGE
PR: $PR" \
  $MODULE GDB $VERSION_TAG
