# $Id: Makefile.bfd.inc 705412 2015-03-31 11:59:28Z ib-builder $

# These are the set of files normally created as a part of libbfd
# which are needed for gdb 6.5.

CFLAGS+= -I${GDBDIR}/bfd -I${GDBDIR}/opcodes

_bfd_srcs=   \
	bfd/archive.c \
	bfd/archive64.c \
	bfd/archures.c \
	bfd/bfd.c \
	bfd/bfdio.c \
	bfd/binary.c \
	bfd/cache.c \
	bfd/coffgen.c \
	bfd/corefile.c \
	bfd/dwarf1.c \
	bfd/dwarf2.c \
	bfd/ecofflink.c \
	bfd/elf-eh-frame.c \
	bfd/elf-strtab.c \
	bfd/elf-vxworks.c \
	bfd/elf.c \
	bfd/elf32-gen.c \
	bfd/elf32.c \
	bfd/elf64-gen.c \
	bfd/elf64.c \
	bfd/elflink.c \
	bfd/format.c \
	bfd/hash.c \
	bfd/ihex.c \
	bfd/init.c \
	bfd/libbfd.c \
	bfd/linker.c \
	bfd/merge.c \
	bfd/opncls.c \
	bfd/reloc.c \
	bfd/section.c \
	bfd/simple.c \
	bfd/srec.c \
	bfd/stab-syms.c \
	bfd/stabs.c \
	bfd/syms.c \
	bfd/targets.c \
	bfd/tekhex.c

.if ${TARGET_ARCH} == "arm"

_bfd_srcs+= \
	bfd/cpu-arm.c \
	bfd/elf32-arm.c

DEFAULT_VECTOR= bfd_elf32_bigarm_vec
ARCHS= ${TARGET_ARCH}
VECS= ${DEFAULT_VECTOR} \
	bfd_elf32_littlearm_vec \
	bfd_elf32_big_generic_vec

.endif


.if ${TARGET_ARCH} == "mips"

_bfd_srcs+= \
	bfd/cpu-mips.c \
	bfd/elf32-mips.c \
	bfd/elf64-mips.c \
	bfd/elfxx-mips.c

DEFAULT_VECTOR= bfd_elf32_bigmips_vec
ARCHS= ${TARGET_ARCH}
VECS= ${DEFAULT_VECTOR} \
	bfd_elf32_littlemips_vec \
	bfd_elf64_bigmips_vec \
	bfd_elf64_littlemips_vec \
	bfd_elf64_little_generic_vec \
	bfd_elf64_big_generic_vec \
	bfd_elf32_little_generic_vec \
	bfd_elf32_big_generic_vec

.endif

.if ${TARGET_ARCH} == "i386"

_bfd_srcs+= \
	bfd/cpu-i386.c \
	bfd/coff-i386.c \
	bfd/cofflink.c \
	bfd/elf32-i386.c \
	bfd/xcofflink.c

ARCHS= ${TARGET_ARCH}
DEFAULT_VECTOR= bfd_elf32_i386_freebsd_vec
VECS= ${DEFAULT_VECTOR} \
	i386coff_vec \
	bfd_elf32_little_generic_vec \
	bfd_elf32_big_generic_vec

.endif

.if ${TARGET_ARCH} == "amd64"

_bfd_srcs+= \
	bfd/cpu-i386.c \
	bfd/coff-i386.c \
	bfd/cofflink.c \
	bfd/xcofflink.c \
	bfd/elf64-x86-64.c \
	bfd/elf32-i386.c

ARCHS= ${TARGET_ARCH}
DEFAULT_VECTOR=bfd_elf64_x86_64_freebsd_vec
VECS= ${DEFAULT_VECTOR} \
	bfd_elf64_x86_64_vec \
	bfd_elf32_i386_freebsd_vec \
	i386coff_vec \
	bfd_elf64_little_generic_vec \
	bfd_elf64_big_generic_vec \
	bfd_elf32_little_generic_vec \
	bfd_elf32_big_generic_vec

.endif

.if ${TARGET_ARCH} == "powerpc"

_bfd_srcs+= \
	bfd/cpu-powerpc.c \
	bfd/cpu-rs6000.c \
	bfd/elf32-ppc.c \
	bfd/ppcboot.c

ARCHS= ${TARGET_ARCH} rs6000
DEFAULT_VECTOR= bfd_elf32_powerpc_vec
VECS= ${DEFAULT_VECTOR} \
	bfd_elf32_powerpcle_vec	\
	ppcboot_vec

.endif

.if ${MACHINE_ARCH} == "powerpc64"

_bfd_srcs+= \
	bfd/cpu-powerpc.c \
	bfd/cpu-rs6000.c \
	bfd/elf32-ppc.c \
	bfd/elf64-ppc.c \
	bfd/ppcboot.c

ARCHS= ${MACHINE_ARCH} rs6000
DEFAULT_VECTOR= bfd_elf64_powerpc_vec
VECS= ${DEFAULT_VECTOR} \
	bfd_elf32_powerpc_vec \
	bfd_elf32_powerpcle_vec	\
	bfd_elf64_powerpcle_vec	\
	ppcboot_vec

.endif


SELARCH=

# amd64 is a special case of i386
.if ${TARGET_ARCH} == "amd64"
SELARCH= &bfd_i386_arch
.elif ${TARGET_ARCH} == "arm"
SELARCH= &bfd_arm_arch
.elif ${TARGET_ARCH} == "sparc64"
# sparc64 is a special case of sparc
SELARCH= &bfd_sparc_arch
.elif ${TARGET_ARCH} == "powerpc64"
# powerpc64 is a special case of powerpc
SELARCH= &bfd_rs6000_arch,&bfd_powerpc_arch
.else

# All of the other architectures are listed as themselves.
.for _a in ${ARCHS}
.if ${SELARCH} == ""
SELARCH+= &bfd_${_a}_arch
.else
SELARCH+= ,&bfd_${_a}_arch
.endif
.endfor

.endif # ${TARGET_ARCH} 

# Use the SELARCH just calculated
CFLAGS+= -DSELECT_ARCHITECTURES="${SELARCH}"

SELVEC=
.for _v in ${VECS}
CFLAGS+= -DHAVE_${_v}
.if ${SELVEC} == ""
SELVEC+= &${_v}
.else
SELVEC+= ,&${_v}
.endif
.endfor

CFLAGS+= -DSELECT_VECS="${SELVEC}"

.ifdef DEFAULT_VECTOR
CFLAGS+= -DDEFAULT_VECTOR=${DEFAULT_VECTOR}
.endif

GENSRCS+=	bfdver.h
bfdver.h: ${.PARSEDIR}/${.PARSEFILE}
	BFDVER=`grep ^AM_INIT_AUTOMAKE ${GDBDIR}/bfd/configure.in | \
	 sed -e 's/AM_INIT_AUTOMAKE(bfd, *\([0-9.]*\)).*/\1/'`;\
	bfd_version=`echo $$BFDVER | sed \
	 -e 's/\([^\.]*\)\.*\([^\.]*\)\.*\([^\.]*\)\.*\([^\.]*\)\.*\([^\.]*\).*/\1.00\2.00\3.00\4.00\5/' \
         -e 's/\([^\.]*\)\..*\(..\)\..*\(..\)\..*\(..\)\..*\(..\)$$/\1\2\3\4\5/'`; \
	echo "#define BFD_VERSION	$$bfd_version"	> ${.TARGET};\
	grep BFD_VERSION_DATE < ${GDBDIR}/bfd/version.h >> ${.TARGET};\
	echo "#define BFD_VERSION_STRING \"$$BFDVER $$bfd_version\"" >> ${.TARGET}

GENSRCS+=	elf32-target.h elf64-target.h
elf32-target.h: bfd/elfxx-target.h
	sed -e s/NN/32/g ${.ALLSRC} > ${.TARGET}

elf64-target.h: bfd/elfxx-target.h
	sed -e s/NN/64/g ${.ALLSRC} > ${.TARGET}

GENSRCS+=	targmatch.h
targmatch.h:	bfd/targmatch.sed bfd/config.bfd
	sed -f ${.ALLSRC:M*.sed} ${.ALLSRC:M*.bfd} > ${.TARGET}
